@@ -4,20 +4,18 @@ Client
 
 The embedly object that interacts with the service
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 import re
 import httplib2
 import json
-try:
-    from urllib import quote, urlencode
-except ImportError:
-    # py3k
-    from urllib.parse import quote, urlencode
-
+from urllib import quote, urlencode
 
 from .models import Url
 
-USER_AGENT = 'Mozilla/5.0 (compatible; embedly-python/0.3;)'
+
+def get_user_agent():
+    from . import __version__
+    return 'Mozilla/5.0 (compatible; embedly-python/%s;)' % __version__
 
 
 class Embedly(object):
@@ -25,22 +23,24 @@ class Embedly(object):
     Client
 
     """
-    def __init__(self, key=None, user_agent=USER_AGENT, timeout=60):
+    def __init__(self, key=None, user_agent=None, timeout=60):
         """
         Initialize the Embedly client
 
-        :param user_agent: User Agent passed to Embedly
-        :type user_agent: str
         :param key: Embedly Pro key
         :type key: str
+        :param user_agent: User Agent passed to Embedly
+        :type user_agent: str
+        :param timeout: timeout for HTTP connection attempts
+        :type timeout: int
 
         :returns: None
         """
-        self.user_agent = user_agent
-        self.timeout = timeout
         self.key = key
-        self.services = []
+        self.user_agent = user_agent or get_user_agent()
+        self.timeout = timeout
 
+        self.services = []
         self._regex = None
 
     def get_services(self):
@@ -49,22 +49,24 @@ class Embedly(object):
         the list of supported providers and their regexes
         """
 
-        if self.services: return self.services
+        if self.services:
+            return self.services
 
         url = 'http://api.embed.ly/1/services/python'
 
         http = httplib2.Http(timeout=self.timeout)
-        headers = {'User-Agent' : self.user_agent}
+        headers = {'User-Agent': self.user_agent,
+                   'Connection': 'close'}
         resp, content = http.request(url, headers=headers)
 
         if resp['status'] == '200':
-            resp_data = json.loads(content)
+            resp_data = json.loads(content.decode('utf-8'))
             self.services = resp_data
 
-            #build the regex that we can use later.
+            # build the regex that we can use later
             _regex = []
-            for each in self.get_services():
-                _regex.append('|'.join(each.get('regex',[])))
+            for each in self.services:
+                _regex.append('|'.join(each.get('regex', [])))
 
             self._regex = re.compile('|'.join(_regex))
 
@@ -95,10 +97,10 @@ class Embedly(object):
             raise ValueError('%s requires a url or a list of urls given: %s' %
                              (method.title(), url_or_urls))
 
-        #A flag we can use instead of calling isinstance all the time.
+        # a flag we can use instead of calling isinstance() all the time
         multi = isinstance(url_or_urls, list)
 
-        # Throw an error early for too many URLs
+        # throw an error early for too many URLs
         if multi and len(url_or_urls) > 20:
             raise ValueError('Embedly accepts only 20 urls at a time. Url '
                              'Count:%s' % len(url_or_urls))
@@ -107,7 +109,7 @@ class Embedly(object):
 
         key = kwargs.get('key', self.key)
 
-        #make sure that a key was set on the client or passed in.
+        # make sure that a key was set on the client or passed in
         if not key:
             raise ValueError('Requires a key. None given: %s' % key)
 
@@ -124,7 +126,8 @@ class Embedly(object):
 
         http = httplib2.Http(timeout=self.timeout)
 
-        headers = {'User-Agent': self.user_agent}
+        headers = {'User-Agent': self.user_agent,
+                   'Connection': 'close'}
 
         resp, content = http.request(url, headers=headers)
 
